import pandas as pd
import numpy as np



def uplift_metric(score, vas, groups, debug=False):
    """
    Calculate uplift revenue on top 20%
    """
    
    # split data to showed \ not showed
    gr1_mat = np.zeros([sum(groups==1), 2])
    gr1_mat[:, 0] = vas[groups==1]
    gr1_mat[:, 1] = score[groups==1]

    gr0_mat = np.zeros([sum(groups==0), 2])
    gr0_mat[:, 0] = vas[groups==0]
    gr0_mat[:, 1] = score[groups==0]
    
    # sort by score and get only VAS amounts
    vas0 = gr0_mat[(-gr0_mat[:,1]).argsort()][:, 0]
    vas1 = gr1_mat[(-gr1_mat[:,1]).argsort()][:, 0]

    # cut top
    top_rate = 0.2
    top_vas0 = vas0[:int(len(vas0) * top_rate)]
    top_vas1 = vas1[:int(len(vas1) * top_rate)]

    # calc uplift
    uplift = np.sum(top_vas1) - np.mean(top_vas0)*len(top_vas1)
    
    if debug:
        return uplift, top_vas0, top_vas1
    else:
        return uplift
